"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveDir = exports.resolveFile = void 0;
const fs = require("fs");
const path = require("path");
/**
 * resolve a file or directory in the project workspace
 * @param from starting directory or file path
 * @param name file name to resolve
 * @param parent parent directory (of last call)
 * @internal
 */
function _resolveFile(from, name, parent) {
    const fp = path.join(from, name);
    if (fs.existsSync(fp)) {
        return fp;
    }
    else if (from !== parent) { // `dir === parent` when traversal tops out
        return _resolveFile(path.dirname(from), name, from);
    }
}
/**
 * resolve a file upwards in the project workspace
 * @param from starting directory or file path
 * @param name file name to resolve
 */
function resolveFile(from, name) {
    return _resolveFile(from, name);
}
exports.resolveFile = resolveFile;
/**
 * resolve a directory upwards in the project workspace
 * @param from starting directory or file path
 * @param name directory name to resolve
 */
function resolveDir(from, name) {
    return _resolveFile(from, name);
}
exports.resolveDir = resolveDir;
